<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Fastrack_Wp_Helper_Meta {
	// decide to print each meta box type
	public static function print_meta( $meta_box ) {

		if ( empty( $meta_box['default'] ) ) {
			$meta_box['default'] = '';
		}

		switch ( $meta_box['type'] ) {

			case "open" :
				self::print_meta_open_div( $meta_box );
				break;
			case "close" :
				self::print_meta_close_div( $meta_box );
				break;
			case "header":
				self::print_meta_header( $meta_box );
				break;
			case "text":
				self::print_meta_text( $meta_box );
				break;
			case "description":
				self::print_description( $meta_box );
				break;
			case "inputtext":
				self::print_meta_input_text( $meta_box );
				break;
			case "colorpicker":
			case "colourpicker":
				self::print_meta_colour_picker( $meta_box );
				break;
			case "upload":
				self::print_meta_upload( $meta_box );
				break;
			case "uploadpdf":
				self::print_meta_upload_pdf( $meta_box );
				break;
			case "textarea":
				self::print_meta_input_textarea( $meta_box );
				break;
			case "checkbox":
				self::print_meta_input_checkbox( $meta_box );
				break;
			case "combobox":
				self::print_meta_input_combobox( $meta_box );
				break;
			case "combobox_plus":
				self::print_meta_input_combobox_plus( $meta_box );
				break;
			case "radioenabled":
				self::print_meta_input_radioenabled( $meta_box );
				break;
			case "radioimage":
				self::print_meta_input_radioimage( $meta_box );
				break;
			case "imagepicker":
				self::print_image_picker( $meta_box );
				break;

		}

	}

	// nonce Verification
	public static function set_nonce() {
		wp_nonce_field( plugin_basename( __FILE__ ), 'myplugin_noncename' );
	}

	// header => name, title
	public static function print_meta_header( $args ) {

		extract( $args );
		$meta_id = ( isset( $meta_id ) ) ? $meta_id : '';

		?>

		<div id="meta-header" class="<?php echo $meta_id; ?>">
			<h2><?php _e( $title, 'pxp_back_office' ); ?></h2>
		</div>

		<?php

	}

	// text => name, text
	public static function print_meta_text( $args ) {

		extract( $args );

		?>

		<div class="meta-body">
			<div class="meta-title pb10">
				<?php _e( $title, 'pxp_back_office' ); ?>
			</div>
		</div>

		<?php

	}

	// text => name, title, value, default
	public static function print_meta_input_text( $args ) {
		extract( $args );

		?>

		<div class="meta-body"<?php if ( isset( $id ) ) {
			echo ' id="' . $name . '"';
		} ?> style="display: inline-block; width: 49%;">
			<div class="meta-title">
				<label for="<?php echo $name; ?>"><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">
				<input type="text" name="<?php echo $name; ?>" id="<?php echo $name; ?>" value="<?php

				echo ( $value == '' ) ? esc_html( $default ) : esc_html( $value );

				?>"/>
			</div>

			<?php if ( isset( $description ) ) { ?>

				<div class="meta-description"> <?php echo $description; ?> </div>

			<?php } ?>

			<br class=clear>
		</div>

		<?php

	}

	// colorpicker => name, title, value, default
	public static function print_meta_colour_picker( $args ) {
		extract( $args );

		?>

		<div class="meta-body"<?php if ( isset( $id ) ) {
			echo ' id="' . $name . '"';
		} ?>>
			<div class="meta-title">
				<label for="<?php echo $name; ?>"><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">
				<input type="text" name="<?php echo $name; ?>" class="color-picker" id="<?php echo $name; ?>"
				       value="<?php

				       echo ( $value == '' ) ? esc_html( $default ) : esc_html( $value );

				       ?>"/>
			</div>

			<?php if ( isset( $description ) ) { ?>

				<div class="meta-description"> <?php echo $description; ?> </div>

			<?php } ?>

			<br class=clear>
		</div>

		<?php

	}

	// text => name, title, value, default
	public static function print_description( $args ) {
		extract( $args );

		?>

		<div class="meta-body">
			<div class="meta-title">
				<label><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="only-description"> <?php echo $description; ?> </div>
			<br class=clear>
		</div>

		<?php

	}

	// text => name, title, value
	public static function print_meta_upload( $args ) {

		extract( $args );

		?>

		<div class="meta-body">
			<div class="meta-title">
				<label for="<?php echo $name; ?>"><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">
				<div class="meta-input-example-image" id="meta-input-example-image">

					<?php

					$image_src = '';

					if ( ! empty( $value ) ) {

						$image_src         = wp_get_attachment_image_src( $value, 'full' );
						$thumb_src_preview = wp_get_attachment_image_src( $value, '150x150' );
						echo '<img src="' . $thumb_src_preview[0] . '" />';

					}

					?>

				</div>
				<input name="<?php echo $name; ?>" type="hidden" id="upload_image_attachment_id" value="<?php

				echo ( empty( $value ) ) ? esc_html( $default ) : esc_html( $value );

				?>"/>
				<input id="upload_image_text_meta" class="upload_image_text_meta" type="text"
				       value="<?php echo ( empty( $image_src[0] ) ) ? '' : $image_src[0]; ?>"/>
				<input class="upload_image_button_meta" type="button" value="Upload"/>
			</div>

			<?php if ( isset( $description ) ) { ?>

				<div class="meta-description"><?php echo $description; ?></div>

			<?php } ?>

			<br class=clear>
		</div>

		<?php

	}

	// text => name, title, value
	public static function print_meta_upload_pdf( $args ) {

		extract( $args );

		?>

		<div class="meta-body">
			<div class="meta-title">
				<label for="<?php echo $name; ?>"><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">
				<input name="<?php echo $name; ?>" type="hidden" id="upload_pdf_attachment_id" value="<?php

				echo ( empty( $value ) ) ? esc_html( $default ) : esc_html( $value );

				$file_url = '';
				if ( ! empty( $value ) ) {
					$file_url = wp_get_attachment_url( $value );
				}
				?>"/>
				<input id="upload_pdf_text_meta" class="upload_pdf_text_meta" type="text"
				       value="<?php echo ( empty( $file_url ) ) ? '' : $file_url; ?>"/>
				<input class="upload_pdf_button_meta button" type="button" value="Upload"/>
			</div>

			<?php if ( isset( $description ) ) { ?>

				<div class="meta-description"><?php echo $description; ?></div>

			<?php } ?>

			<br class=clear>
		</div>

		<?php

	}

	// textarea => name, title, value, default
	public static function print_meta_input_textarea( $args ) {

		extract( $args );

		?>

		<div class="meta-body <?php echo str_replace( '[]', '', $name ); ?>-wrapper">
			<div class="meta-title">
				<label for="<?php echo $name; ?>"><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">
					<textarea name="<?php echo $name; ?>" id="<?php echo $name; ?>"
					          class="<?php echo str_replace( '[]', '', $name ); ?>"><?php

						echo ( $value == '' ) ? esc_html( $default ) : esc_html( $value );

						?></textarea>
			</div>

			<?php if ( isset( $description ) ) { ?>

				<div class="meta-description"><?php echo $description; ?></div>

			<?php } ?>

			<br class="clear">
		</div>

		<?php

	}

	// checkbox => name, title, value
	public static function print_meta_input_checkbox( $args ) {

		extract( $args );

		?>

		<div class="meta-body">
			<div class="meta-title">
				<label for="<?php echo $name; ?>"><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">
				Not yet implement
			</div>

			<?php if ( isset( $description ) ) { ?>

				<div class="meta-description"><?php echo $description; ?></div>

			<?php } ?>

			<br class=clear>
		</div>

		<?php
	}

	// combobox => name, title, value, options[]
	public static function print_meta_input_combobox( $args ) {

		extract( $args );

		$value = ( empty( $value ) ) ? $default : $value;

		?>

		<div class="meta-body">
			<div class="meta-title">
				<label for="<?php echo $name; ?>"><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">
				<div class="combobox">
					<select name="<?php echo $name; ?>" id="<?php echo str_replace( '[]', '', $name ); ?>">

						<?php foreach ( $options as $option ) { ?>

							<option rel="<?php echo $option; ?>" <?php if ( $option == esc_html( $value ) ) {
								echo 'selected';
							} ?> ><?php echo $option; ?></option>

						<?php } ?>

					</select>
				</div>
			</div>

			<?php if ( isset( $description ) ) { ?>

				<div class="meta-description"><?php echo $description; ?></div>

			<?php } ?>

			<br class=clear>
		</div>

		<?php

	}

	// combobox => name, title, value, options[]
	public static function print_meta_input_combobox_plus( $args ) {
		extract( $args );

		$value = ( empty( $value ) ) ? $default : $value;

		?>

		<div class="meta-body">
			<div class="meta-title">
				<label for="<?php echo $name; ?>"><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">
				<div class="combobox">
					<select name="<?php echo $name; ?>" id="<?php echo str_replace( '[]', '', $name ); ?>">

						<?php foreach ( $options as $k => $v ) { ?>

							<option value="<?php echo $k; ?>" <?php if ( $k == esc_html( $value ) ) {
								echo 'selected';
							} ?> ><?php echo $v; ?></option>

						<?php } ?>

					</select>
				</div>
			</div>

			<?php if ( isset( $description ) ) { ?>

				<div class="meta-description"><?php echo $description; ?></div>

			<?php } ?>

			<br class=clear>
		</div>

		<?php

	}

	// radioenabled => name, title, value
	public static function print_meta_input_radioenabled( $args ) {

		extract( $args );

		?>

		<div class="meta-body">
			<div class="meta-title">
				<label for="<?php echo $name; ?>"><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">
				<input type="radio" name="<?php echo $name; ?>"
				       value="enabled" <?php if ( $value == 'enabled' || $value == '' ) {
					echo 'checked';
				} ?>> Enable &nbsp&nbsp&nbsp
				<input type="radio" name="<?php echo $name; ?>" value="disable" <?php if ( $value == 'disable' ) {
					echo 'checked';
				} ?>> Disable
			</div>

			<?php if ( isset( $description ) ) { ?>

				<div class="meta-description"><?php echo $description; ?></div>

			<?php } ?>

			<br class=clear>
		</div>

		<?php

	}


	// radioimage => name, title, type, value, option=>array(value, image)
	public static function print_meta_input_radioimage( $args ) {

		extract( $args );

		?>

		<div class="meta-body">
			<div class="meta-title">
				<label><?php _e( $title, 'pxp_back_office' ); ?></label>
			</div>
			<div class="meta-input">

				<?php foreach ( $options as $option ) { ?>

					<div class='radio-image-wrapper'>
						<label for="<?php echo $option['value']; ?>">
							<img src=<?php echo PIXELTHEME_PATH . $option['image'] ?> alt=<?php echo $name; ?>>

							<div id="check-list"></div>
						</label>
						<input type="radio" name="<?php echo $name; ?>" value="<?php echo $option['value']; ?>" <?php

						if ( $value == $option['value'] ) {

							echo 'checked';

						} else if ( $value == '' && $default == $option['value'] ) {

							echo 'checked';

						}

						?> id="<?php echo $option['value']; ?>" class="<?php echo $name; ?>">
					</div>

				<?php } ?>
				<br class=clear>
			</div>
			<br class=clear>
		</div>
		<?php
	}

	// imagepicker => title, name=>array(num,image,title,caption,link)
	public static function print_image_picker( $args ) {

		extract( $args );

		?>

		<div class="meta-body image-picker-wrapper">
			<div class="meta-input-slider">
				<div class="image-picker" id="image-picker">
					<input type='hidden' class="slider-num" id="slider-num" name='<?php

					echo ( isset( $name['slider-num'] ) ) ? $name['slider-num'] . '[]' : '';

					?>' value=<?php

					echo empty( $value ) ? 0 : $value->childNodes->length;

					?>/>

					<div class="selected-image" id="selected-image">
						<div id="selected-image-none"></div>
						<ul>
							<li id="default" class="default">
								<div class="selected-image-wrapper">
									<img src="#"/>

									<div class="selected-image-element">
										<div id="edit-image" class="edit-image"></div>
										<div id="unpick-image" class="unpick-image"></div>
										<br class="clear">
									</div>
								</div>
								<input type="hidden" class='slider-image-url' id='<?php echo $name['image']; ?>'/>

								<div id="slider-detail-wrapper" class="slider-detail-wrapper">
									<div id="slider-detail" class="slider-detail">
										<div class="meta-title meta-detail-title"><?php _e( 'SLIDER TITLE',
												'pxp_back_office' ); ?></div>
										<div class="meta-detail-input meta-input"><input type="text"
										                                                 id='<?php echo $name['title']; ?>'/>
										</div>
										<br class="clear">
										<hr class="separator">
										<div class="meta-title meta-detail-title"><?php _e( 'SLIDER CAPTION',
												'pxp_back_office' ); ?></div>
										<div class="meta-detail-input meta-input"><textarea
												id='<?php echo $name['caption']; ?>'></textarea></div>
										<br class="clear">
										<hr class="separator">
										<div class="meta-title meta-detail-title"><?php _e( 'LINK TYPE',
												'pxp_back_office' ); ?></div>
										<div class="meta-input meta-detail-input">
											<div class="combobox">
												<select id='<?php echo $name['linktype']; ?>'>
													<option selected>No Link</option>
													<option>Lightbox</option>
													<option>Link to URL</option>
													<option>Link to Video</option>
												</select>
											</div>
											<div class="meta-title meta-detail-title ml0 mt5"
											     rel="url"><?php _e( 'URL PATH', 'pxp_back_office' ); ?></div>
											<div class="meta-title meta-detail-title ml0 mt5"
											     rel="video"><?php _e( 'VIDEO PATH (ONLY FOR ANYTHING SLIDER)',
													'pxp_back_office' ); ?></div>
											<div><input class="mt10" type="text" id='<?php echo $name['link']; ?>'/>
											</div>
										</div>
										<br class="clear">

										<div class="meta-detail-done-wrapper">
											<input type="button" id="pxp-detail-edit-done" class="pxp-button"
											       value="Done"/><br class="clear">
										</div>
									</div>
								</div>
							</li>

							<?php

							if ( ! empty( $value ) ) {

								foreach ( $value->childNodes as $slider ) { ?>

									<li class="slider-image-init">
										<div class="selected-image-wrapper">
											<img src="<?php

											$thumb_src_preview = wp_get_attachment_image_src( find_xml_value( $slider,
												'image' ), '160x110' );
											echo $thumb_src_preview[0];

											?>"/>

											<div class="selected-image-element">
												<div id="edit-image" class="edit-image"></div>
												<div id="unpick-image" class="unpick-image"></div>
												<br class="clear">
											</div>
										</div>
										<input type="hidden" class='slider-image-url'
										       name='<?php echo $name['image']; ?>[]'
										       id='<?php echo $name['image']; ?>[]'
										       value="<?php echo find_xml_value( $slider, 'image' ); ?>"/>

										<div id="slider-detail-wrapper" class="slider-detail-wrapper">
											<div id="slider-detail" class="slider-detail">
												<div class="meta-title meta-detail-title"><?php _e( 'SLIDER TITLE',
														'pxp_back_office' ); ?></div>
												<div class="meta-detail-input meta-input"><input type="text"
												                                                 name='<?php echo $name['title']; ?>[]'
												                                                 id='<?php echo $name['title']; ?>[]'
												                                                 value="<?php echo find_xml_value( $slider,
													                                                 'title' ); ?>"/>
												</div>
												<br class="clear">
												<hr class="separator">
												<div class="meta-title meta-detail-title"><?php _e( 'SLIDER CAPTION',
														'pxp_back_office' ); ?></div>
												<div class="meta-detail-input meta-input"><textarea
														name='<?php echo $name['caption']; ?>[]'
														id='<?php echo $name['caption']; ?>[]'><?php echo find_xml_value( $slider,
															'caption' ); ?></textarea></div>
												<br class="clear">
												<hr class="separator">
												<div class="meta-title meta-detail-title"><?php _e( 'LINK TYPE',
														'pxp_back_office' ); ?></div>
												<div class="meta-input meta-detail-input">
													<div class="combobox">
														<?php $linktype_val = find_xml_value( $slider, 'linktype' ); ?>
														<select name='<?php echo $name['linktype']; ?>[]'
														        id='<?php echo $name['linktype']; ?>'>
															<option <?php echo ( $linktype_val == 'No Link' ) ? "selected" : ''; ?> >
																No Link
															</option>
															<option <?php echo ( $linktype_val == 'Lightbox' ) ? "selected" : ''; ?>>
																Lightbox
															</option>
															<option <?php echo ( $linktype_val == 'Link to URL' ) ? "selected" : ''; ?>>
																Link to URL
															</option>
															<option <?php echo ( $linktype_val == 'Link to Video' ) ? "selected" : ''; ?>>
																Link to Video
															</option>
														</select>
													</div>
													<div class="meta-title meta-detail-title ml0 mt5"
													     rel="url"><?php _e( 'URL PATH', 'pxp_back_office' ); ?></div>
													<div class="meta-title meta-detail-title ml0 mt5"
													     rel="video"><?php _e( 'VIDEO PATH (ONLY FOR ANYTHING SLIDER)',
															'pxp_back_office' ); ?></div>
													<div><input class="mt10" type="text"
													            name='<?php echo $name['link']; ?>[]'
													            id='<?php echo $name['link']; ?>[]'
													            value="<?php echo find_xml_value( $slider,
														            'link' ); ?>"/></div>
												</div>
												<br class="clear">

												<div class="meta-detail-done-wrapper">
													<input type="button" id="pxp-detail-edit-done" class="pxp-button"
													       value="Done"/><br class="clear">
												</div>
											</div>
										</div>
									</li>

									<?php

								}

							}

							?>

						</ul>
						<br class=clear>

						<div id="show-media" class="show-media">
							<span id="show-media-text"></span>

							<div id="show-media-image"></div>
						</div>
					</div>
					<div class="media-image-gallery-wrapper">
						<div class="media-image-gallery" id="media-image-gallery">
							<?php get_media_image(); ?>
						</div>
					</div>
				</div>
			</div>
			<br class=clear>
		</div>

		<?php

	}

	// open => id
	public static function print_meta_open_div( $args ) {

		extract( $args );

		?>

		<div id="<?php echo $id; ?>" class="<?php echo $id; ?>" >

		<?php

	}

	// close
	public static function print_meta_close_div( $args ) {

		?>

		</div>

		<?php

	}

	// function that save the meta to database if new data is exists and is not equals to old one
	public static function save_meta_data( $post_id, $new_data, $old_data, $name ) {

		if ( $new_data == $old_data ) {

			add_post_meta( $post_id, $name, $new_data, true );

		} else if ( ! $new_data ) {

			delete_post_meta( $post_id, $name, $old_data );

		} else if ( $new_data != $old_data ) {

			update_post_meta( $post_id, $name, $new_data, $old_data );

		}
	}
}