<?php
if ( !defined( 'ABSPATH' ) ) {
	exit;
}

class Fastrack_Wp_Post_Type_Product {

	const POST_TYPE = "product";

	static $meta_fields = array();

	public static function register() {

		add_action( 'save_post_' . self::POST_TYPE, array( 'Fastrack_Wp_Post_Type_Product', 'save_product_post_type_meta' ) );
		add_action( 'add_meta_boxes', array( 'Fastrack_Wp_Post_Type_Product', 'add_product_data' ) );
		add_filter( 'manage_edit-product_columns', array( 'Fastrack_Wp_Post_Type_Product', 'add_new_columns' ) );
		self::load_meta_fields();


		add_action( 'wp_ajax_get_product_categories', array( 'Fastrack_Wp_Post_Type_Product', 'get_product_categories' ) );
		add_action( 'wp_ajax_nopriv_get_product_categories', array( 'Fastrack_Wp_Post_Type_Product', 'get_product_categories' ) );
	}



	public static function add_product_data() {
		add_meta_box( 'product-option', __( 'Dealer Info', Fastrack_Wp_Main::$text_domain ), array( 'Fastrack_Wp_Post_Type_Product', 'add_product_dealer_elements' ), self::POST_TYPE, 'side', 'low' );
		add_meta_box( 'product-data', __( 'Details', Fastrack_Wp_Main::$text_domain ), array( 'Fastrack_Wp_Post_Type_Product', 'add_product_data_elements' ), self::POST_TYPE, 'normal', 'high' );
	}

	public static function add_product_dealer_elements() {

		global $post;
		echo '<div id="pxp-overlay-wrapper">';
		?>
		<div class="product-option-meta" id="product-dealer-meta"> <?php
			Fastrack_Wp_Helper_Meta::set_nonce();

			foreach ( self::get_product_meta_boxes_dealer() as $meta_box ) {
				$meta_box[ 'value' ] = get_post_meta( $post->ID, $meta_box[ 'name' ], true );
				Fastrack_Wp_Helper_Meta::print_meta( $meta_box );
			}
			?> </div> <?php
		echo '</div>';
	}

	public static function add_product_data_elements() {

		global $post;
		echo '<div id="pxp-overlay-wrapper">';
		?>
		<div class="product-option-meta" id="product-data-meta"> <?php
			Fastrack_Wp_Helper_Meta::set_nonce();

			foreach ( self::$meta_fields as $meta_box ) {
				$meta_box[ 'value' ] = get_post_meta( $post->ID, $meta_box[ 'name' ], true );
				Fastrack_Wp_Helper_Meta::print_meta( $meta_box );
			}
			?> </div> <?php
		echo '</div>';
	}

	public static function save_product_option_meta( $post_id ) {

		foreach ( self::$meta_fields as $edit_meta_box ) {
			if ( isset( $_POST[ $edit_meta_box[ 'name' ] ] ) ) {
				$new_data = stripslashes( $_POST[ $edit_meta_box[ 'name' ] ] );
			} else {
				$new_data = '';
			}

			$old_data = get_post_meta( $post_id, $edit_meta_box[ 'name' ], true );
			Fastrack_Wp_Helper_Meta::save_meta_data( $post_id, $new_data, $old_data, $edit_meta_box[ 'name' ] );
		}
		foreach ( self::get_product_meta_boxes_dealer() as $edit_meta_box ) {
			if ( isset( $_POST[ $edit_meta_box[ 'name' ] ] ) ) {
				$new_data = stripslashes( $_POST[ $edit_meta_box[ 'name' ] ] );
			} else {
				$new_data = '';
			}

			$old_data = get_post_meta( $post_id, $edit_meta_box[ 'name' ], true );
			Fastrack_Wp_Helper_Meta::save_meta_data( $post_id, $new_data, $old_data, $edit_meta_box[ 'name' ] );
		}
	}

	public static function save_product_post_type_meta( $post_id ) {
		// Save data of page
		if ( isset( $_POST[ 'post_type' ] ) && self::POST_TYPE === $_POST[ 'post_type' ] ) {
			if ( !current_user_can( 'edit_post', $post_id ) ) {
				return;
			}
			self::save_product_option_meta( $post_id );
			Fastrack_Wp_Post_Type_Dealer::save_dealer_option_meta( $post_id );
		}
	}

	private static function get_product_meta_boxes_dealer() {
		$partner_names	 = array( 0 => __( '-- Select a Dealer --', Fastrack_Wp_Main::$text_domain ) );
		$args			 = array(
			'post_type'		 => Fastrack_Wp_Post_Type_Dealer::POST_TYPE,
			'post_status'	 => 'publish',
			'orderby'		 => 'title',
			'order'			 => 'ASC',
			'posts_per_page' => - 1
		);
		$my_query		 = new WP_Query( $args );
		foreach ( $my_query->get_posts() as $p ) {
			/** @var WP_Post $p */
			$partner_names[ $p->ID ] = $p->post_title;
		}
		wp_reset_query();

		return array(
			"Dealer Name" => array(
				'title'		 => __( 'Dealer Name', Fastrack_Wp_Main::$text_domain ),
				'name'		 => 'product-option-dealerid',
				'type'		 => 'combobox_plus',
				'default'	 => 0,
				'options'	 => $partner_names,
				'hr'		 => 'none',
			)
		);
	}

	private static function load_meta_fields() {
		if ( empty( self::$meta_fields ) ) {
			self::$meta_fields = array(
				"Make"		 => array(
					'title'	 => __( 'MAKE', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-data-make',
					'type'	 => 'inputtext',
				),
				"Model"		 => array(
					'title'	 => __( 'MODEL', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-data-model',
					'type'	 => 'inputtext',
				),
				"Location"	 => array(
					'title'	 => __( 'LOCATION', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-data-location',
					'type'	 => 'inputtext'
				),
				"Condition"	 => array(
					'title'	 => __( 'CONDITION', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-data-condition',
					'type'	 => 'inputtext'
				),
				"Year"		 => array(
					'title'	 => __( 'YEAR', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-data-year',
					'type'	 => 'inputtext'
				),
				"Odometer"		 => array(
					'title'	 => __( 'Odometer', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-odometer',
					'type'	 => 'inputtext'
				),
				"Truck Config"		 => array(
					'title'	 => __( 'Truck Config', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-truck-config',
					'type'	 => 'inputtext'
				),
				"Susp Options"		 => array(
					'title'	 => __( 'Susp Options', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-susp-options',
					'type'	 => 'inputtext'
				),
				"Cab Option"		 => array(
					'title'	 => __( 'Cab Option', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-cab-option',
					'type'	 => 'inputtext'
				),
				"Tare"		 => array(
					'title'	 => __( 'Tare', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-tare',
					'type'	 => 'inputtext'
				),
				"GVM"		 => array(
					'title'	 => __( 'GVM', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-gvm',
					'type'	 => 'inputtext'
				),
				"GCM"		 => array(
					'title'	 => __( 'GCM', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-gcm',
					'type'	 => 'inputtext'
				),
				"Eng Type"		 => array(
					'title'	 => __( 'Eng Type', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-eng-type',
					'type'	 => 'inputtext'
				),
				"Eng Power"		 => array(
					'title'	 => __( 'Eng Power', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-eng-power',
					'type'	 => 'inputtext'
				),
				"Eng Size"		 => array(
					'title'	 => __( 'Eng Size', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-eng-size',
					'type'	 => 'inputtext'
				),
				"Engine Make"		 => array(
					'title'	 => __( 'Engine Make', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-engine-make',
					'type'	 => 'inputtext'
				),
				"Fuel Capacity"		 => array(
					'title'	 => __( 'Fuel Capacity', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-fuel-capacity',
					'type'	 => 'inputtext'
				),
				"Transmission"		 => array(
					'title'	 => __( 'Transmission', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-transmission',
					'type'	 => 'inputtext'
				),
				"Differential"		 => array(
					'title'	 => __( 'Differential', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-differential',
					'type'	 => 'inputtext'
				),
				"Turntable/ Coupling"		 => array(
					'title'	 => __( 'Turntable/ Coupling', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-turntable-coupling',
					'type'	 => 'inputtext'
				),
				"Audio/Visual System"		 => array(
					'title'	 => __( 'Audio/Visual System', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-audio-visual-system',
					'type'	 => 'inputtext'
				),
				"Comms/Radio"		 => array(
					'title'	 => __( 'Comms/Radio', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-comms-radio',
					'type'	 => 'inputtext'
				),
				"Front Tyre Size"		 => array(
					'title'	 => __( 'Front Tyre Size', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-front-tyre-size',
					'type'	 => 'inputtext'
				),
				"Front Tyre Type"		 => array(
					'title'	 => __( 'Front Tyre Type', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-front-tyre-type',
					'type'	 => 'inputtext'
				),
				"Front Tyre Cond"		 => array(
					'title'	 => __( 'Front Tyre Cond', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-front-tyre-cond',
					'type'	 => 'inputtext'
				),
				"Rear Tyre Size"		 => array(
					'title'	 => __( 'Rear Tyre Size', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-rear-tyre-size',
					'type'	 => 'inputtext'
				),
				"Rear Tyre Type"		 => array(
					'title'	 => __( 'Rear Tyre Type', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-rear-tyre-type',
					'type'	 => 'inputtext'
				),
				"Bullbar"		 => array(
					'title'	 => __( 'Bullbar', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-bullbar',
					'type'	 => 'inputtext'
				),
				"External Colour"		 => array(
					'title'	 => __( 'External Colour', Fastrack_Wp_Main::$text_domain ),
					'name'	 => 'product-external-colour',
					'type'	 => 'inputtext'
				),
				"Listing"	 => array(
					'title'		 => __( 'LISTING', Fastrack_Wp_Main::$text_domain ),
					'name'		 => 'product-data-listing',
					'type'		 => 'combobox',
					'options'	 => array( 'New', 'Demo', 'Used' )
				),
				"Ad Type"		 => array(
					'title'	  => __( 'Ad Type', Fastrack_Wp_Main::$text_domain ),
					'name'	  => 'product-data-adtype',
					'type'	  => 'combobox',
					'default' => '',
					'options' => array(
							"NA",
							"Standard",
							"Upgrade Level 1",
							"Upgrade Level 2",
							"Upgrade Level 3",
							"Upgrade Level 4"
					),
				),
			);
		}
	}

	public static function get_image( $post_ID ) {
		$post_thumbnail_id = get_post_thumbnail_id( $post_ID );
		if ( $post_thumbnail_id ) {
			$post_thumbnail_img = wp_get_attachment_image_src( $post_thumbnail_id, 'featured_preview' );
			return $post_thumbnail_img[ 0 ];
		}
	}

	

	public static function add_new_columns( $new_columns ) {
		//$new_columns[ 'image' ] = __( 'Image' );
		return $new_columns;
	}

	// Products Search Form functions
	public static function get_product_meta_values( $key = '') {
		global $wpdb;

		if( empty( $key ) )
			return;

		// $r = $wpdb->get_col( $wpdb->prepare( "
		// SELECT pm.meta_value FROM {$wpdb->postmeta} pm
		// LEFT JOIN {$wpdb->posts} p ON p.ID = pm.post_id
		// WHERE pm.meta_key = '%s'
		// AND p.post_status = '%s'
		// AND p.post_type = '%s'
		// ", $key, $status, $type ) );

		$values = $wpdb->get_col("SELECT DISTINCT meta_value FROM $wpdb->postmeta WHERE meta_key = '". $key ."' ORDER BY meta_value ASC");

		//print_r($values);
		$options = '<option value="">All makes</option>';
		foreach($values as $k => $v){

			if($_REQUEST['make'] == $v )
			{
				$selected ="selected=selected";
			}
			else
			{ $selected ="";}

			$options .= '<option value="'. $v .'" '.$selected.'>'. $v .'</option>';
		}
		echo $options;
	}

	public static function get_product_categories($parent = 0, $sub = '') {
		
		if ($_REQUEST["id"] != '') $parent = $_REQUEST["id"];
		$args = array(
			//'fields' => 'names',
				'parent' => $parent,
		);
		$terms = get_terms('product_cat', $args);
		if ( ! empty( $terms ) && ! is_wp_error( $terms ) ){
			$options = '';
			foreach ( $terms as $term ) {

				if($_REQUEST['category'] == $term->term_id)
				{
					$selected ="selected=selected";
				}
				else if($_REQUEST['subcategory'] == $term->term_id){

					$selected ="selected=selected";
				}
				else
				{ $selected ="";}

				$options .= '<option value="'. $term->term_id .'" '.$selected.'>'. $term->name .'</option>';
			}
			echo $options;
		}

		if ($_REQUEST["id"] != '') die();
	}


	public static function get_mmac_product_image($id=0) {
		$img = wp_get_attachment_url(get_post_thumbnail_id( $id));
		if($img == '') {
			$img = PLUGIN_Fastrack_Wp_ROOT_URL . 'assets/img/coming-soon.jpg';
		}
		return $img;
	}
    

	public static function get_mmac_dealer_phone_number($phone = '') {
		if ($phone != '') {
			$phone_first = substr($phone, 0, 3);
			$phone_rest = str_repeat('X', strlen($phone) - 1);
			$phone = '<div id="dealer-number" data-all="'. $phone .'" style="cursor:pointer;">'. $phone_first . $phone_rest .' reveal</div>';
			//$phone = '<div id="dealer-number" data-all="'. $phone .'" style="cursor:pointer;" onClick="jQuery(this).html(jQuery(this).data(\'all\'));ga(\'send\',\'event\',\'banner\',\'click\',\'Content right\',1,{\'nonInteraction\':1});">'. $phone_first . $phone_rest .' reveal</div>';
		}

		return $phone;
	}

	private static function get_featured_images( $post_id = null ) {
		if ( is_null( $post_id ) ) {
			global $post;
			$post_id = $post->ID;
		}

		$dfiImages = get_post_meta( $post_id, 'dfiFeatured', true );

		$retImages = array();
		if ( ! empty( $dfiImages ) && is_array( $dfiImages ) ) {
			$dfiImages = array_filter( $dfiImages );

			$count = 0;
			foreach ( $dfiImages as $dfiImage ) {
				$dfiImageTrimmed = self::_separate( $dfiImage );
				$dfiImageFull    = self::_separate( $dfiImage, 'full' );

				try {

					$retImages[ $count ]['thumb']         = self::_get_real_upload_path( $dfiImageTrimmed );
					$retImages[ $count ]['full']          = self::_get_real_upload_path( $dfiImageFull );
					$retImages[ $count ]['attachment_id'] = self::get_image_id( $retImages[ $count ]['full'] );

				} catch ( Exception $e ) { /* Ignore the exception and continue with other featured images */
				}

				$count ++;
			}
		}

		return $retImages;
	}

	private static function _separate( $urlString, $state = 'thumb' ) {
		$imagePiece = explode( ',', $urlString );

		if ( $state == 'thumb' ) {
			return isset( $imagePiece[1] ) ? $imagePiece[1] : null;
		}

		return isset( $imagePiece[1] ) ? $imagePiece[1] : null;
	}

	private static function _get_real_upload_path( $img ) {
		$upload_url = self::_get_upload_url();
		//check if upload path is already attached
		if ( strpos( $img, $upload_url ) !== false || preg_match('/https?:\/\//', $img) ) {
			return $img;
		}

		return $upload_url . $img;
	}

	private static function get_image_id( $image_url ) {
		global $wpdb;
		$upload_url = self::_get_upload_url();
		$attachment_id = self::_get_attachment_id( $image_url );
		if ( is_null( $attachment_id ) ) {
			//check if the image is edited image
			//and try to get the attachment id
			$image_url = str_replace( $upload_url . "/", '', $image_url );
			$row       = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM {$wpdb->prefix}postmeta WHERE meta_value = %s", $image_url ) );
			if ( ! is_null( $row ) ) {
				$attachment_id = $row;
			}
		}

		return $attachment_id;
	}

	private static function _get_attachment_id( $image_url ) {
		global $wpdb;
		return $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM {$wpdb->prefix}posts WHERE guid = %s", $image_url ) );
	}

	private static function _get_upload_url() {
		$protocol = ( ( ! empty( $_SERVER['HTTPS'] ) && $_SERVER['HTTPS'] != 'off' ) ||
			         ( ! empty( $_SERVER['SERVER_PORT'] ) && $_SERVER['SERVER_PORT'] == 443 ) ) ? "https://" : "http://";
        $upload_url=wp_upload_dir();
		$upload_url = preg_replace( '#^https?://#', '', $upload_url['baseurl'] );

		return $protocol . $upload_url;
	}
}
