<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Fastrack_Wp_Post_Type_Dealer {

	const POST_TYPE = "dealer";
	static $meta_fields = array();

	public static function register() {
		register_post_type( self::POST_TYPE, self::get_post_type_args() );

		register_taxonomy(
			"dealer-category", array( self::POST_TYPE ), array(
			"hierarchical"      => true,
			"label"             => "Dealer Categories",
			"singular_label"    => "Dealer Category",
			"show_in_nav_menus" => false,
			"rewrite"           => true
		) );
		register_taxonomy_for_object_type( 'dealer-category', self::POST_TYPE );

		add_action( 'save_post_' . self::POST_TYPE,
			array( 'Fastrack_Wp_Post_Type_Dealer', 'save_dealer_post_type_meta' ) );
		add_action( 'add_meta_boxes', array( 'Fastrack_Wp_Post_Type_Dealer', 'add_dealer_data' ) );
		self::load_meta_fields();
	}
    
	public static function get_post_type_args() {
		$labels = array(
			'name'               => _x( 'Dealers', 'Dealer General Name', Fastrack_Wp_Main::$text_domain ),
			'singular_name'      => _x( 'Dealer Item', 'Dealer Singular Name', Fastrack_Wp_Main::$text_domain ),
			'add_new'            => _x( 'Add New Dealer', 'Add New Dealer Name', Fastrack_Wp_Main::$text_domain ),
			'add_new_item'       => __( 'Add New Dealer', Fastrack_Wp_Main::$text_domain ),
			'new_item'           => __( 'New Dealer', Fastrack_Wp_Main::$text_domain ),
			'view_item'          => 'View Dealer',
			'search_items'       => __( 'Search Dealer', Fastrack_Wp_Main::$text_domain ),
			'not_found'          => __( 'Nothing found', Fastrack_Wp_Main::$text_domain ),
			'not_found_in_trash' => __( 'Nothing found in Trash', Fastrack_Wp_Main::$text_domain ),
			'parent_item_colon'  => ''
		);

		return array(
			'labels'              => $labels,
			'public'              => true,
			'publicly_queryable'  => true,
			'show_ui'             => true,
			'query_var'           => true,
			'rewrite'             => true,
			'capability_type'     => 'post',
			'hierarchical'        => false,
			'menu_position'       => 4,
			"show_in_nav_menus"   => false,
			'exclude_from_search' => false,
			'supports'            => array( 'title', 'editor', 'thumbnail' ) //,'excerpt','comments'
		);
	}


	public static function add_dealer_data() {
		add_meta_box( 'dealer-data', __( 'Dealer Data', Fastrack_Wp_Main::$text_domain ),
			array( 'Fastrack_Wp_Post_Type_Dealer', 'add_dealer_data_elements' ),
			self::POST_TYPE, 'normal', 'high'
		);
	}

	public static function add_dealer_data_elements() {

		global $post;
		echo '<div id="pxp-overlay-wrapper">';

		?>
		<div class="dealer-option-meta" id="dealer-data-meta"> <?php

			Fastrack_Wp_Helper_Meta::set_nonce();

			foreach ( self::$meta_fields as $meta_box ) {
				$meta_box['value'] = get_post_meta( $post->ID, $meta_box['name'], true );
				Fastrack_Wp_Helper_Meta::print_meta( $meta_box );
			}

			?> </div> <?php

		echo '</div>';
	}

	public static function save_dealer_option_meta( $post_id ) {

		foreach ( self::$meta_fields as $edit_meta_box ) {
			if ( isset( $_POST[ $edit_meta_box['name'] ] ) ) {
				$new_data = stripslashes( $_POST[ $edit_meta_box['name'] ] );
			} else {
				$new_data = '';
			}

			$old_data = get_post_meta( $post_id, $edit_meta_box['name'], true );
			Fastrack_Wp_Helper_Meta::save_meta_data( $post_id, $new_data, $old_data, $edit_meta_box['name'] );
		}
	}

	public static function save_dealer_post_type_meta( $post_id ) {
		// Save data of page
		if ( isset( $_POST['post_type'] ) && self::POST_TYPE === $_POST['post_type'] ) {
			if ( ! current_user_can( 'edit_post', $post_id ) ) {
				return;
			}
			self::save_dealer_option_meta( $post_id );
		}
	}

	private static function load_meta_fields() {
		if ( empty( self::$meta_fields ) ) {
			self::$meta_fields = array(
				"ID"          => array(
					'title' => __( 'ID', Fastrack_Wp_Main::$text_domain ),
					'name'  => 'dealer-data-xmlid',
					'type'  => 'inputtext',
				),
				"Phone"       => array(
					'title' => __( 'PHONE', Fastrack_Wp_Main::$text_domain ),
					'name'  => 'dealer-data-phone',
					'type'  => 'inputtext',
				),
				"Email"       => array(
					'title' => __( 'EMAIL', Fastrack_Wp_Main::$text_domain ),
					'name'  => 'dealer-data-email',
					'type'  => 'inputtext'
				),
				"Address"     => array(
					'title' => __( 'ADDRESS', Fastrack_Wp_Main::$text_domain ),
					'name'  => 'dealer-data-address',
					'type'  => 'textarea'
				),
				"City"        => array(
					'title' => __( 'CITY', Fastrack_Wp_Main::$text_domain ),
					'name'  => 'dealer-data-city',
					'type'  => 'inputtext'
				),
				"State"       => array(
					'title' => __( 'STATE', Fastrack_Wp_Main::$text_domain ),
					'name'  => 'dealer-data-state',
					'type'  => 'inputtext'
				),
				"Postal Code" => array(
					'title' => __( 'POSTAL CODE', Fastrack_Wp_Main::$text_domain ),
					'name'  => 'dealer-data-postalcode',
					'type'  => 'inputtext'
				),
				"Country"     => array(
					'title' => __( 'COUNTRY', Fastrack_Wp_Main::$text_domain ),
					'name'  => 'dealer-data-country',
					'type'  => 'inputtext'
				)
			);
		}
	}
}