<?php

if ( !defined( 'ABSPATH' ) ) {
	exit;
}

class Fastrack_Wp_Settings {

	static $setting_name = "fastrack_wp_opts";
	static $search_page	 = "search-page";

	function __construct() {
		if ( is_admin() ) { // admin actions
			add_action( 'admin_menu', array( $this, 'add_menu' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
			add_action( 'wp_ajax_fastrack_wp_xml', array( $this, 'ajax_actions' ) );
			add_action( 'wp_ajax_fastrack_wp_xml', array( $this, 'ajax_actions' ) );

			$this->load_settings();
		}
		add_action( 'wp_fastrack_import_xml_cron', array( $this, 'import_xml_sch' ) );
	}

	function add_menu() {
		add_submenu_page( 'fastrack_wp', 'Import', 'Import', 'manage_options', 'wp_import_settings', array( $this, 'settings_page' ) );
	}

	function settings_page() {
		$file_id	 = "";
		if ( isset( $_REQUEST[ 'submit' ] ) && ($_REQUEST[ 'submit' ] == "Import") )
			$file_id	 = $this->upload_xml();
		$options	 = $this->settings;
        $optionz     = self::get_settings();
		$text_domain = Fastrack_Wp_Main::$text_domain;
		Fastrack_Wp_Main::render( "settings", compact( 'options', 'optionz', 'text_domain', 'file_id' ) );
	}

	function upload_xml() {

		$uploaddir	 = PLUGIN_Fastrack_Wp_TEMP_PATH;
		array_map( 'unlink', glob( $uploaddir . "*.xml" ) );
		$id			 = time();
		$uploadfile	 = $uploaddir . $id . ".xml";

		if ( move_uploaded_file( $_FILES[ 'fileToUpload' ][ 'tmp_name' ], $uploadfile ) ) {
			return $id;
		} else {
			return "";
		}
	}

    
    
	function plugin_activate() {
		$this->create_search_page();

		if ( !file_exists( ABSPATH . 'xml-data/' ) ) {
			mkdir( ABSPATH . 'xml-data/', 0777, true );
		}

		if ( !file_exists( ABSPATH . 'backup-xml/' ) ) {
			mkdir( ABSPATH . 'backup-xml/', 0777, true );
		}
       if( !wp_next_scheduled( 'wp_fastrack_xml_cron_import' ) ) {  
           wp_schedule_event( time(), 'everythirtyminute', 'wp_fastrack_import_xml_cron' );  
        }
	}
    
    
	function plugin_deactivate() {
		wp_clear_scheduled_hook('wp_fastrack_import_xml_cron');
	}

	public function enqueue_scripts() {
		wp_enqueue_style( 'wp-fastrack', Fastrack_Wp_Main::wp_get_css_script_file_path( 'admin.css' ) );
	}

	public function import_xml_sch() {
        $optionz['cron_schedule'] = time();
        update_option( self::$setting_name, $optionz );
		$this->import_xml_full();
	}

	public function ajax_actions() {


		$act = isset( $_REQUEST[ 'm' ] ) ? $_REQUEST[ 'm' ] : '';
		switch ( $act ) {
			case "save_opt":
				$this->save_settings();
				$this->load_settings();

				break;
			case "run_now":
				$file	 = isset( $_POST[ 'file' ] ) ? $_POST[ 'file' ] : 0;
				$this->import_xml_part( $_POST[ 'step' ], $file);
				break;
			case "import_all":
			case "test":
				$this->import_xml_full();
				break;
			case "import_xml":
				$import	 = new Fastrack_Wp_Import( $this->settings[ 'xml_data_folder' ] );
				$import->import_mmacxml_file( $_REQUEST[ 'file_id' ], $_REQUEST[ 'start' ] );
				//echo json_encode( array( "start" => $_REQUEST[ 'start' ] + 20, "percent" => $_REQUEST[ 'start' ] + 20 ) );
				break;
		}
		//Don't forget to always exit in the ajax function.
		die();
	}

	public function save_settings() {
		parse_str( $_POST[ 'data' ], $params );
		if ( isset( $params[ 'options' ] ) )
			foreach ( $params[ 'options' ] as $k => $v )
				$this->settings[ $k ] = $v;
		update_option( self::$setting_name, $this->settings );
	}

	public function import_xml_full() {
		$this->load_settings();
		$import_obj = new Fastrack_Wp_Import( $this->settings[ 'xml_data_folder' ] );
		$import_obj->mmac_xml_import_cron();
	}

	public function import_xml_part( $step = 'start', $file = 0 ) {
		$ret = array();
		$dir = $this->settings[ 'xml_data_folder' ];

		if ( $file )
			$dir = PLUGIN_Fastrack_Wp_TEMP_PATH;

		$import_obj		 = new Fastrack_Wp_Import( $dir );
		$method			 = "mmac_xml_import_$step";
		$ret[ 'left' ]	 = $import_obj->$method();
		ob_end_clean();
		echo json_encode( $ret );
	}

	public function load_settings() {

		$this->settings = get_option( self::$setting_name, array() );

		if ( !isset( $this->settings[ 'xml_data_folder' ] ) )
			$this->settings[ 'xml_data_folder' ] = ABSPATH . 'xml-data/';
	}

	function create_search_page() {
		global $user_ID, $wpdb;

		$query	 = $wpdb->prepare(
		'SELECT ID FROM ' . $wpdb->posts . '
        WHERE post_title = %s
        AND post_type = \'page\'', self::$search_page
		);
		$post_id = $wpdb->get_var( $query );


		if ( $wpdb->num_rows ) {
			$this->save_search_page_id( $post_id );
		} else {
			$new_post	 = array(
				'post_title'	 => self::$search_page,
				'post_content'	 => '[Fastrack_Wp_search_content]',
				'post_status'	 => 'publish',
				'post_date'		 => date( 'Y-m-d H:i:s' ),
				'post_author'	 => '',
				'post_type'		 => 'page',
				'post_category'	 => array( 0 )
			);
			$post_id	 = wp_insert_post( $new_post );
			$this->save_search_page_id( $post_id );
		}
	}

	function save_search_page_id( $id ) {
		$this->settings[ 'search_page_id' ] = $id;
		update_option( self::$setting_name, $this->settings );
		$this->load_settings();
	}

	public static function get_settings() {
		return get_option( self::$setting_name, array() );
	}

}
